@@ -1,6 +1,11 @@
 from icevision.models.utils import *
 
-from icevision.models.torchvision_models import faster_rcnn, mask_rcnn, retinanet
+from icevision.models.torchvision_models import (
+    faster_rcnn,
+    mask_rcnn,
+    retinanet,
+    keypoint_rcnn,
+)
 
 # Soft dependencies
 from icevision.soft_dependencies import SoftDependencies
