@@ -1,4 +1,4 @@
-__all__ = ["get_data_dir"]
+__all__ = ["get_data_dir", "get_root_dir"]
 
 from icevision.imports import *
 
@@ -11,3 +11,7 @@ data_dir.mkdir(exist_ok=True)
 
 def get_data_dir():
     return data_dir
+
+
+def get_root_dir():
+    return root_dir
